unit Fields1;
//
// This program demonstrates several features of SQLQuery and can be used to
// verify functionality. It tests all different field types supported and their mapping
// to TFields. Operations are timed so you can test the speed of different
// operations. It also demonstrates the use of a trace callback.
//
// Before running the demo, please change the SQLServer1 DataBaseName,
// ServerName, UserName and Password properties to suit your environment.
// On first run it will create an empty table 'TestSQLQuery'
//--------------------------------------------------------------------------
interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, Grids, DBGrids, Db, SQLServer, Mask, DBCtrls, ExtCtrls,
  ComCtrls, Fields2;

type
  TForm1 = class(TForm)
    SQLServer1: TSQLServer;
    SQLQuery1: TSQLQuery;
    DataSource1: TDataSource;
    SQLUpdate1: TSQLUpdate;
    StatusBar1: TStatusBar;
    Panel1: TPanel;
    DBNavigator1: TDBNavigator;
    Button1: TButton;
    Button2: TButton;
    Panel2: TPanel;
    DBGrid1: TDBGrid;
    ScrollBox1: TScrollBox;
    Label1: TLabel;
    Label2: TLabel;
    Label3: TLabel;
    Label4: TLabel;
    Label5: TLabel;
    Label6: TLabel;
    Label7: TLabel;
    Label8: TLabel;
    Label9: TLabel;
    Label10: TLabel;
    Label11: TLabel;
    Label12: TLabel;
    Label13: TLabel;
    Label14: TLabel;
    Label15: TLabel;
    Label16: TLabel;
    Label17: TLabel;
    DBEdit1: TDBEdit;
    DBEdit2: TDBEdit;
    DBEdit3: TDBEdit;
    DBEdit4: TDBEdit;
    DBEdit5: TDBEdit;
    DBEdit6: TDBEdit;
    DBCheckBox1: TDBCheckBox;
    DBEdit7: TDBEdit;
    DBEdit8: TDBEdit;
    DBEdit9: TDBEdit;
    DBEdit10: TDBEdit;
    DBEdit11: TDBEdit;
    DBEdit12: TDBEdit;
    DBEdit13: TDBEdit;
    DBEdit14: TDBEdit;
    DBEdit15: TDBEdit;
    DBCheckBox2: TDBCheckBox;
    DBEdit16: TDBEdit;
    DBEdit17: TDBEdit;
    DBMemo1: TDBMemo;
    Splitter1: TSplitter;
    SQLQuery2: TSQLQuery;
    Button3: TButton;
    Button4: TButton;
    procedure Button1Click(Sender: TObject);
    procedure DBGrid1TitleClick(Column: TColumn);
    procedure Button2Click(Sender: TObject);
    procedure CountRecords(DataSet: TDataSet);
    procedure FormShow(Sender: TObject);
    procedure SQLQuery1BeforePost(DataSet: TDataSet);
    procedure SQLQuery1AfterPost(DataSet: TDataSet);
    procedure Button3Click(Sender: TObject);
    procedure Button4Click(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
  private
    Timer : cardinal;
    procedure DoOpen;
  public
    { Public declarations }
  end;

var
  Form1: TForm1;

implementation              
{$R *.DFM}

//
// This is the procedure used as a callback routine when hooking
// into SQLQuery:s trace
//
procedure Trace(TraceMessage: string);
begin
     if Form2=nil then exit; 
     if Form2.Memo1<>nil then Form2.Memo1.Lines.Add(TraceMessage);
end;

procedure TForm1.DoOpen;
begin
     try
        SQLQuery1.Open;
     except on E:EcsSQLError do
            if E.ErrorCode=208 then begin // SQL error codes from SQL Books Online
               SQLQuery2.ExecSQL;
               SQLQuery1.Open;
            end;
     end;
end;

procedure TForm1.Button1Click(Sender: TObject);
var tic1, tic2 : cardinal;
begin                         
     tic1 := GetTickCount;
     if SQLQuery1.Active then begin
        SQLQuery1.Close;              
        Button1.Caption := 'Open';     
     end else begin
          DoOpen;
          Button1.Caption := 'Close';
          SQLQuery1.FieldByName('id').Required := False;
          SQLQuery1.FieldByName('id').ReadOnly := True;
          SQLQuery1.FieldByName('id').Visible := False;
     end;
     tic2 := GetTickCount - tic1;
     StatusBar1.Panels[0].Text := Format('Time=%d ms',[Tic2]);
end;

procedure TForm1.DBGrid1TitleClick(Column: TColumn);
begin
     with SQLQuery1 do begin
          Edit;
          Column.Field.Clear;
          Post;
     end;
end;

procedure TForm1.Button2Click(Sender: TObject);
begin
     SQLQuery1.Append;
end;

procedure TForm1.CountRecords(DataSet: TDataSet);
begin
  Statusbar1.Panels[1].Text := Format('Records: %d',[DataSet.RecordCount]);
end;

procedure TForm1.FormShow(Sender: TObject);
begin
     Button1.Click;
end;

procedure TForm1.SQLQuery1BeforePost(DataSet: TDataSet);
begin
     Timer := GetTickCount;
     SQLQuery1.FieldByName('MySmallInt').AsInteger := SQLQuery1.FieldByName('MySmallInt').AsInteger+1;
end;

procedure TForm1.SQLQuery1AfterPost(DataSet: TDataSet);
begin
     StatusBar1.Panels[0].Text := Format('Time=%d ms',[GetTickCount-Timer]);
end;
//
// Enable/Disable trace window
//
procedure TForm1.Button3Click(Sender: TObject);
begin
     if Form2.Visible then begin
        Form2.Close;
        SQLServer1.DBTrace(False);
     end else begin
        Form2.Show;
        SQLServer1.RegisterTraceCallback(@Trace);
        SQLServer1.DBTrace(True);
     end;
end;

procedure TForm1.Button4Click(Sender: TObject);
begin
     with SQLQuery1 do begin
          Edit;
          FieldByName('MyReal').Clear;
          Post;
     end;
end;

procedure TForm1.FormClose(Sender: TObject; var Action: TCloseAction);
begin
        SQLServer1.DBTrace(False); 
end;

end.                     
